@@ -1,24 +1,22 @@
 from kilroy_face_client_py_sdk.client import FaceClient
-from kilroy_face_client_py_sdk.models import (
-    Config,
-    ConfigNotification,
-    ConfigSchema,
-    ConfigSetReply,
-    ConfigSetRequest,
-    FitPostsReply,
-    FitPostsRequest,
-    PostScore,
-    FitScoresReply,
-    FitScoresRequest,
-    GenerateReply,
-    GenerateRequest,
-    MetricsInfo,
-    MetricsNotification,
+from kilroy_face_py_shared import (
+    JSON,
+    JSONSchema,
     PostSchema,
+    StatusEnum,
     Status,
     StatusNotification,
-    StepReply,
-    StepRequest,
+    Config,
+    ConfigSchema,
+    ConfigNotification,
+    ConfigSetRequest,
+    ConfigSetReply,
+    PostRequest,
+    PostReply,
+    ScoreRequest,
+    ScoreReply,
+    ScrapRequest,
+    ScrapReply,
 )
 from kilroy_face_client_py_sdk.resources import (
     resource,
